Class: RSpecTracer::Rails::Railtie Private

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/rspec_tracer/rails/railtie.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Rails lifecycle adapter. Only required by ‘lib/rspec_tracer/rails.rb` when `defined?(::Rails::Railtie)` is true, so loading this file in a non-Rails process is not expected and will raise NameError.

Defines the Railtie class + registers one initializer that logs a single confirmation line. The actual ActiveSupport::Notifications subscribers for ActionView template renders, I18n lookups, and schema/factory/fixture tracking live in ‘notifications.rb` and `i18n_tracking.rb` and are wired by `Engine.setup`.